@@ -8,7 +8,7 @@ import re
 
 import nltk
 
-from dictionary import Dictionary
+from .dictionary import Dictionary
 
 
 class Phrase_parse:
