@@ -9,7 +9,7 @@ import re
 
 import nltk
 
-from dictionary import Dictionary
+from .dictionary import Dictionary
 
 
 class Relation_extraciton:
