@@ -7,13 +7,11 @@ Created on Sat Oct  3 21:45:27 2020
 
 import os
 import re
-
 import nltk
 import openpyxl
 import xlrd
-
-from dictionary import Dictionary
-from log_wp import Log_wp
+from .dictionary import Dictionary
+from .log_wp import Log_wp
 
 
 class Table_extraction:
