@@ -12,15 +12,15 @@ import re
 import nltk
 import openpyxl
 
-from Phrase_parse import Phrase_parse
-from Relation_extraciton_dp import Relation_extraciton
-from T_pre_processor import T_pre_processor
-from dictionary import Dictionary
-from get_full_text import Filter_text
-from log_wp import Log_wp
-from output_modified_triple import Table_extraction
-from pre_processor import Pre_processor
-from sentence_positioner import Sentence_Positioner
+from .Phrase_parse import Phrase_parse
+from .Relation_extraciton_dp import Relation_extraciton
+from .T_pre_processor import T_pre_processor
+from .dictionary import Dictionary
+from .get_full_text import Filter_text
+from .log_wp import Log_wp
+from .output_modified_triple import Table_extraction
+from .pre_processor import Pre_processor
+from .sentence_positioner import Sentence_Positioner
 
 property_list = ['solvus', 'density', 'liquidus', 'solidus']
 
